@@ -22,6 +22,24 @@ module Google
   module Apis
     module StorageV1
       
+      class AdvanceRelocateBucketOperationRequest
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class AnywhereCache
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class AnywhereCaches
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Bucket
         class Representation < Google::Apis::Core::JsonRepresentation; end
         
@@ -51,6 +69,30 @@ module Google
         
         class Encryption
           class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+          class CustomerManagedEncryptionEnforcementConfig
+            class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+            include Google::Apis::Core::JsonObjectSupport
+          end
+          
+          class CustomerSuppliedEncryptionEnforcementConfig
+            class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+            include Google::Apis::Core::JsonObjectSupport
+          end
+          
+          class GoogleManagedEncryptionEnforcementConfig
+            class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+            include Google::Apis::Core::JsonObjectSupport
+          end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+        
+        class HierarchicalNamespace
+          class Representation < Google::Apis::Core::JsonRepresentation; end
         
           include Google::Apis::Core::JsonObjectSupport
         end
@@ -73,6 +115,24 @@ module Google
           include Google::Apis::Core::JsonObjectSupport
         end
         
+        class IpFilter
+          class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+          class PublicNetworkSource
+            class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+            include Google::Apis::Core::JsonObjectSupport
+          end
+          
+          class VpcNetworkSource
+            class Representation < Google::Apis::Core::JsonRepresentation; end
+          
+            include Google::Apis::Core::JsonObjectSupport
+          end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+        
         class Lifecycle
           class Representation < Google::Apis::Core::JsonRepresentation; end
           
@@ -160,6 +220,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class BucketStorageLayout
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+        class CustomPlacementConfig
+          class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+        
+        class HierarchicalNamespace
+          class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Buckets
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -202,6 +280,24 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class Folder
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+        class PendingRenameInfo
+          class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
+      class Folders
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class GoogleLongrunningListOperationsResponse
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -265,6 +361,12 @@ module Google
       class Object
         class Representation < Google::Apis::Core::JsonRepresentation; end
         
+        class Contexts
+          class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+        
         class CustomerEncryption
           class Representation < Google::Apis::Core::JsonRepresentation; end
         
@@ -304,6 +406,12 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class ObjectCustomContextPayload
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class Objects
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -322,6 +430,18 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class RelocateBucketRequest
+        class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+        class DestinationCustomPlacementConfig
+          class Representation < Google::Apis::Core::JsonRepresentation; end
+        
+          include Google::Apis::Core::JsonObjectSupport
+        end
+      
+        include Google::Apis::Core::JsonObjectSupport
+      end
+      
       class RewriteResponse
         class Representation < Google::Apis::Core::JsonRepresentation; end
       
@@ -340,6 +460,45 @@ module Google
         include Google::Apis::Core::JsonObjectSupport
       end
       
+      class AdvanceRelocateBucketOperationRequest
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :expire_time, as: 'expireTime', type: DateTime
+      
+          property :ttl, as: 'ttl'
+        end
+      end
+      
+      class AnywhereCache
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :admission_policy, as: 'admissionPolicy'
+          property :anywhere_cache_id, as: 'anywhereCacheId'
+          property :bucket, as: 'bucket'
+          property :create_time, as: 'createTime', type: DateTime
+      
+          property :id, as: 'id'
+          property :kind, as: 'kind'
+          property :pending_update, as: 'pendingUpdate'
+          property :self_link, as: 'selfLink'
+          property :state, as: 'state'
+          property :ttl, as: 'ttl'
+          property :update_time, as: 'updateTime', type: DateTime
+      
+          property :zone, as: 'zone'
+        end
+      end
+      
+      class AnywhereCaches
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :items, as: 'items', class: Google::Apis::StorageV1::AnywhereCache, decorator: Google::Apis::StorageV1::AnywhereCache::Representation
+      
+          property :kind, as: 'kind'
+          property :next_page_token, as: 'nextPageToken'
+        end
+      end
+      
       class Bucket
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -359,9 +518,16 @@ module Google
           property :encryption, as: 'encryption', class: Google::Apis::StorageV1::Bucket::Encryption, decorator: Google::Apis::StorageV1::Bucket::Encryption::Representation
       
           property :etag, as: 'etag'
+          property :generation, :numeric_string => true, as: 'generation'
+          property :hard_delete_time, as: 'hardDeleteTime', type: DateTime
+      
+          property :hierarchical_namespace, as: 'hierarchicalNamespace', class: Google::Apis::StorageV1::Bucket::HierarchicalNamespace, decorator: Google::Apis::StorageV1::Bucket::HierarchicalNamespace::Representation
+      
           property :iam_configuration, as: 'iamConfiguration', class: Google::Apis::StorageV1::Bucket::IamConfiguration, decorator: Google::Apis::StorageV1::Bucket::IamConfiguration::Representation
       
           property :id, as: 'id'
+          property :ip_filter, as: 'ipFilter', class: Google::Apis::StorageV1::Bucket::IpFilter, decorator: Google::Apis::StorageV1::Bucket::IpFilter::Representation
+      
           property :kind, as: 'kind'
           hash :labels, as: 'labels'
           property :lifecycle, as: 'lifecycle', class: Google::Apis::StorageV1::Bucket::Lifecycle, decorator: Google::Apis::StorageV1::Bucket::Lifecycle::Representation
@@ -380,10 +546,13 @@ module Google
           property :retention_policy, as: 'retentionPolicy', class: Google::Apis::StorageV1::Bucket::RetentionPolicy, decorator: Google::Apis::StorageV1::Bucket::RetentionPolicy::Representation
       
           property :rpo, as: 'rpo'
+          property :satisfies_pzi, as: 'satisfiesPZI'
           property :satisfies_pzs, as: 'satisfiesPZS'
           property :self_link, as: 'selfLink'
           property :soft_delete_policy, as: 'softDeletePolicy', class: Google::Apis::StorageV1::Bucket::SoftDeletePolicy, decorator: Google::Apis::StorageV1::Bucket::SoftDeletePolicy::Representation
       
+          property :soft_delete_time, as: 'softDeleteTime', type: DateTime
+      
           property :storage_class, as: 'storageClass'
           property :time_created, as: 'timeCreated', type: DateTime
       
@@ -434,7 +603,47 @@ module Google
         class Encryption
           # @private
           class Representation < Google::Apis::Core::JsonRepresentation
+            property :customer_managed_encryption_enforcement_config, as: 'customerManagedEncryptionEnforcementConfig', class: Google::Apis::StorageV1::Bucket::Encryption::CustomerManagedEncryptionEnforcementConfig, decorator: Google::Apis::StorageV1::Bucket::Encryption::CustomerManagedEncryptionEnforcementConfig::Representation
+        
+            property :customer_supplied_encryption_enforcement_config, as: 'customerSuppliedEncryptionEnforcementConfig', class: Google::Apis::StorageV1::Bucket::Encryption::CustomerSuppliedEncryptionEnforcementConfig, decorator: Google::Apis::StorageV1::Bucket::Encryption::CustomerSuppliedEncryptionEnforcementConfig::Representation
+        
             property :default_kms_key_name, as: 'defaultKmsKeyName'
+            property :google_managed_encryption_enforcement_config, as: 'googleManagedEncryptionEnforcementConfig', class: Google::Apis::StorageV1::Bucket::Encryption::GoogleManagedEncryptionEnforcementConfig, decorator: Google::Apis::StorageV1::Bucket::Encryption::GoogleManagedEncryptionEnforcementConfig::Representation
+        
+          end
+          
+          class CustomerManagedEncryptionEnforcementConfig
+            # @private
+            class Representation < Google::Apis::Core::JsonRepresentation
+              property :effective_time, as: 'effectiveTime', type: DateTime
+          
+              property :restriction_mode, as: 'restrictionMode'
+            end
+          end
+          
+          class CustomerSuppliedEncryptionEnforcementConfig
+            # @private
+            class Representation < Google::Apis::Core::JsonRepresentation
+              property :effective_time, as: 'effectiveTime', type: DateTime
+          
+              property :restriction_mode, as: 'restrictionMode'
+            end
+          end
+          
+          class GoogleManagedEncryptionEnforcementConfig
+            # @private
+            class Representation < Google::Apis::Core::JsonRepresentation
+              property :effective_time, as: 'effectiveTime', type: DateTime
+          
+              property :restriction_mode, as: 'restrictionMode'
+            end
+          end
+        end
+        
+        class HierarchicalNamespace
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            property :enabled, as: 'enabled'
           end
         end
         
@@ -467,6 +676,34 @@ module Google
           end
         end
         
+        class IpFilter
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            property :allow_all_service_agent_access, as: 'allowAllServiceAgentAccess'
+            property :allow_cross_org_vpcs, as: 'allowCrossOrgVpcs'
+            property :mode, as: 'mode'
+            property :public_network_source, as: 'publicNetworkSource', class: Google::Apis::StorageV1::Bucket::IpFilter::PublicNetworkSource, decorator: Google::Apis::StorageV1::Bucket::IpFilter::PublicNetworkSource::Representation
+        
+            collection :vpc_network_sources, as: 'vpcNetworkSources', class: Google::Apis::StorageV1::Bucket::IpFilter::VpcNetworkSource, decorator: Google::Apis::StorageV1::Bucket::IpFilter::VpcNetworkSource::Representation
+        
+          end
+          
+          class PublicNetworkSource
+            # @private
+            class Representation < Google::Apis::Core::JsonRepresentation
+              collection :allowed_ip_cidr_ranges, as: 'allowedIpCidrRanges'
+            end
+          end
+          
+          class VpcNetworkSource
+            # @private
+            class Representation < Google::Apis::Core::JsonRepresentation
+              collection :allowed_ip_cidr_ranges, as: 'allowedIpCidrRanges'
+              property :network, as: 'network'
+            end
+          end
+        end
+        
         class Lifecycle
           # @private
           class Representation < Google::Apis::Core::JsonRepresentation
@@ -607,6 +844,34 @@ module Google
         end
       end
       
+      class BucketStorageLayout
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :bucket, as: 'bucket'
+          property :custom_placement_config, as: 'customPlacementConfig', class: Google::Apis::StorageV1::BucketStorageLayout::CustomPlacementConfig, decorator: Google::Apis::StorageV1::BucketStorageLayout::CustomPlacementConfig::Representation
+      
+          property :hierarchical_namespace, as: 'hierarchicalNamespace', class: Google::Apis::StorageV1::BucketStorageLayout::HierarchicalNamespace, decorator: Google::Apis::StorageV1::BucketStorageLayout::HierarchicalNamespace::Representation
+      
+          property :kind, as: 'kind'
+          property :location, as: 'location'
+          property :location_type, as: 'locationType'
+        end
+        
+        class CustomPlacementConfig
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            collection :data_locations, as: 'dataLocations'
+          end
+        end
+        
+        class HierarchicalNamespace
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            property :enabled, as: 'enabled'
+          end
+        end
+      end
+      
       class Buckets
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -614,6 +879,7 @@ module Google
       
           property :kind, as: 'kind'
           property :next_page_token, as: 'nextPageToken'
+          collection :unreachable, as: 'unreachable'
         end
       end
       
@@ -622,6 +888,10 @@ module Google
         class Representation < Google::Apis::Core::JsonRepresentation
           property :allow_overwrite, as: 'allowOverwrite'
           property :copy_source_acl, as: 'copySourceAcl'
+          property :created_after_time, as: 'createdAfterTime', type: DateTime
+      
+          property :created_before_time, as: 'createdBeforeTime', type: DateTime
+      
           collection :match_globs, as: 'matchGlobs'
           property :soft_deleted_after_time, as: 'softDeletedAfterTime', type: DateTime
       
@@ -649,6 +919,7 @@ module Google
       class ComposeRequest
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :delete_source_objects, as: 'deleteSourceObjects'
           property :destination, as: 'destination', class: Google::Apis::StorageV1::Object, decorator: Google::Apis::StorageV1::Object::Representation
       
           property :kind, as: 'kind'
@@ -684,9 +955,45 @@ module Google
         end
       end
       
+      class Folder
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :bucket, as: 'bucket'
+          property :create_time, as: 'createTime', type: DateTime
+      
+          property :id, as: 'id'
+          property :kind, as: 'kind'
+          property :metageneration, :numeric_string => true, as: 'metageneration'
+          property :name, as: 'name'
+          property :pending_rename_info, as: 'pendingRenameInfo', class: Google::Apis::StorageV1::Folder::PendingRenameInfo, decorator: Google::Apis::StorageV1::Folder::PendingRenameInfo::Representation
+      
+          property :self_link, as: 'selfLink'
+          property :update_time, as: 'updateTime', type: DateTime
+      
+        end
+        
+        class PendingRenameInfo
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            property :operation_id, as: 'operationId'
+          end
+        end
+      end
+      
+      class Folders
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          collection :items, as: 'items', class: Google::Apis::StorageV1::Folder, decorator: Google::Apis::StorageV1::Folder::Representation
+      
+          property :kind, as: 'kind'
+          property :next_page_token, as: 'nextPageToken'
+        end
+      end
+      
       class GoogleLongrunningListOperationsResponse
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
+          property :kind, as: 'kind'
           property :next_page_token, as: 'nextPageToken'
           collection :operations, as: 'operations', class: Google::Apis::StorageV1::GoogleLongrunningOperation, decorator: Google::Apis::StorageV1::GoogleLongrunningOperation::Representation
       
@@ -699,9 +1006,11 @@ module Google
           property :done, as: 'done'
           property :error, as: 'error', class: Google::Apis::StorageV1::GoogleRpcStatus, decorator: Google::Apis::StorageV1::GoogleRpcStatus::Representation
       
+          property :kind, as: 'kind'
           hash :metadata, as: 'metadata'
           property :name, as: 'name'
           hash :response, as: 'response'
+          property :self_link, as: 'selfLink'
         end
       end
       
@@ -814,6 +1123,8 @@ module Google
           property :content_encoding, as: 'contentEncoding'
           property :content_language, as: 'contentLanguage'
           property :content_type, as: 'contentType'
+          property :contexts, as: 'contexts', class: Google::Apis::StorageV1::Object::Contexts, decorator: Google::Apis::StorageV1::Object::Contexts::Representation
+      
           property :crc32c, as: 'crc32c'
           property :custom_time, as: 'customTime', type: DateTime
       
@@ -834,6 +1145,7 @@ module Google
           property :name, as: 'name'
           property :owner, as: 'owner', class: Google::Apis::StorageV1::Object::Owner, decorator: Google::Apis::StorageV1::Object::Owner::Representation
       
+          property :restore_token, as: 'restoreToken'
           property :retention, as: 'retention', class: Google::Apis::StorageV1::Object::Retention, decorator: Google::Apis::StorageV1::Object::Retention::Representation
       
           property :retention_expiration_time, as: 'retentionExpirationTime', type: DateTime
@@ -848,12 +1160,22 @@ module Google
       
           property :time_deleted, as: 'timeDeleted', type: DateTime
       
+          property :time_finalized, as: 'timeFinalized', type: DateTime
+      
           property :time_storage_class_updated, as: 'timeStorageClassUpdated', type: DateTime
       
           property :updated, as: 'updated', type: DateTime
       
         end
         
+        class Contexts
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            hash :custom, as: 'custom', class: Google::Apis::StorageV1::ObjectCustomContextPayload, decorator: Google::Apis::StorageV1::ObjectCustomContextPayload::Representation
+        
+          end
+        end
+        
         class CustomerEncryption
           # @private
           class Representation < Google::Apis::Core::JsonRepresentation
@@ -917,6 +1239,17 @@ module Google
         end
       end
       
+      class ObjectCustomContextPayload
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :create_time, as: 'createTime', type: DateTime
+      
+          property :update_time, as: 'updateTime', type: DateTime
+      
+          property :value, as: 'value'
+        end
+      end
+      
       class Objects
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
@@ -950,6 +1283,24 @@ module Google
         end
       end
       
+      class RelocateBucketRequest
+        # @private
+        class Representation < Google::Apis::Core::JsonRepresentation
+          property :destination_custom_placement_config, as: 'destinationCustomPlacementConfig', class: Google::Apis::StorageV1::RelocateBucketRequest::DestinationCustomPlacementConfig, decorator: Google::Apis::StorageV1::RelocateBucketRequest::DestinationCustomPlacementConfig::Representation
+      
+          property :destination_kms_key_name, as: 'destinationKmsKeyName'
+          property :destination_location, as: 'destinationLocation'
+          property :validate_only, as: 'validateOnly'
+        end
+        
+        class DestinationCustomPlacementConfig
+          # @private
+          class Representation < Google::Apis::Core::JsonRepresentation
+            collection :data_locations, as: 'dataLocations'
+          end
+        end
+      end
+      
       class RewriteResponse
         # @private
         class Representation < Google::Apis::Core::JsonRepresentation
